@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2018 Vaclav Slavik
+ *  Copyright (C) 1999-2019 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -62,7 +62,9 @@ public:
         /// Change to textctrl should be undoable by the user
         UndoableEdit = 0x01,
         /// Change is due to item change, discard undo buffer
-        ItemChanged = 0x02
+        ItemChanged = 0x02,
+        /// Only update non-text information (auxiliary, fuzzy etc.)
+        DontTouchText = 0x04
     };
 
     /// Constructor
