@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2014-2018 Vaclav Slavik
+ *  Copyright (C) 2014-2019 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -136,15 +136,32 @@ public:
 
     void Highlight(const std::wstring& s, const CallbackType& highlight) override
     {
-        std::wsregex_iterator next(s.begin(), s.end(), m_re);
-        std::wsregex_iterator end;
-        while (next != end)
+        try
         {
-            auto match = *next++;
-            if (match.empty())
-                continue;
-            int pos = static_cast<int>(match.position());
-            highlight(pos, pos + static_cast<int>(match.length()), m_kind);
+            std::wsregex_iterator next(s.begin(), s.end(), m_re);
+            std::wsregex_iterator end;
+            while (next != end)
+            {
+                auto match = *next++;
+                if (match.empty())
+                    continue;
+                int pos = static_cast<int>(match.position());
+                highlight(pos, pos + static_cast<int>(match.length()), m_kind);
+            }
+        }
+        catch (std::regex_error& e)
+        {
+            switch (e.code())
+            {
+                case std::regex_constants::error_complexity:
+                case std::regex_constants::error_stack:
+                    // MSVC version of std::regex in particular can fail to match
+                    // e.g. HTML regex with backreferences on insanely large strings;
+                    // in that case, don't highlight instead of failing outright.
+                    return;
+                default:
+                    throw;
+            }
         }
     }
 
@@ -154,7 +171,7 @@ private:
 };
 
 
-std::wregex RE_HTML_MARKUP(LR"((<\/?[a-zA-Z:-]+(\s+[-:\w]+(=([-:\w+]|"[^"]*"|'[^']*'))?)*\s*\/?>)|(&[^ ;]+;))",
+std::wregex RE_HTML_MARKUP(LR"((<\/?[a-zA-Z0-9:-]+(\s+[-:\w]+(=([-:\w+]|"[^"]*"|'[^']*'))?)*\s*\/?>)|(&[^ ;]+;))",
                            std::regex_constants::ECMAScript | std::regex_constants::optimize);
 
 // php-format per http://php.net/manual/en/function.sprintf.php plus positionals
